@@ -7,6 +7,8 @@ testthat::test_that("We can convert a WAL file to JPEG format.", {
   wal = wal::read.wal(walf);
   tex_jpg = tempfile(fileext = ".jpg");
   wal::wal.export.to.jpeg(wal, tex_jpg);
+
+  testthat::expect_true(file.exists(tex_jpg));
 })
 
 
@@ -17,5 +19,7 @@ testthat::test_that("We can convert a WAL file to PNG format.", {
   wal = wal::read.wal(walf);
   tex_png = tempfile(fileext = ".png");
   wal::wal.export.to.png(wal, tex_png);
+
+  testthat::expect_true(file.exists(tex_png));
 })
 
